DHCPKit VPP
===========

This DHCPKit extension allows DHCPKit to be used as the DHCPv6 server of a Vector Packet Processing (VPP) router. See
https://fd.io/technology and https://wiki.fd.io/view/VPP for more information on VPP.

The `official documentation <http://dhcpkit.readthedocs.io>`_ is hosted by `Read the Docs <https://readthedocs.org>`_.

Documentation
-------------

.. toctree::
    :maxdepth: 2

    config/index
    api/dhcpkit_vpp
    changes
    license
